@@ -373,78 +373,6 @@ class BitStructTest(unittest.TestCase):
         unpacked = unpack('r24t24<', packed)
         self.assertEqual(unpacked, (b'123', 'abc'))
 
-    def test_performance_mixed_types(self):
-        """Test pack/unpack performance with mixed types.
-
-        """
-
-        print()
-
-        time = timeit.timeit("pack('s6u7r40b1t152', "
-                             "-2, 22, b'\x01\x01\x03\x04\x05', "
-                             "True, u'foo fie bar gom gum')",
-                             setup="from bitstruct import pack",
-                             number=50000)
-        print("pack time: {} s ({} s/pack)".format(time, time / 50000))
-
-        time = timeit.timeit(
-            "fmt.pack(-2, 22, b'\x01\x01\x03\x04\x05', "
-            "True, u'foo fie bar gom gum')",
-            setup="import bitstruct ; fmt = bitstruct.compile('s6u7r40b1t152')",
-            number=50000)
-        print("pack time compiled: {} s ({} s/pack)".format(time, time / 50000))
-
-        time = timeit.timeit("unpack('s6u7r40b1t152', "
-                             "b'\\xf8\\xb0\\x08\\x08\\x18 "
-                             "-\\x99\\xbd\\xbc\\x81\\x99"
-                             "\\xa5\\x94\\x81\\x89\\x85"
-                             "\\xc8\\x81\\x9d\\xbd\\xb4"
-                             "\\x81\\x9d\\xd5\\xb4')",
-                             setup="from bitstruct import unpack",
-                             number=50000)
-        print("unpack time: {} s ({} s/unpack)".format(time, time / 50000))
-
-        time = timeit.timeit(
-            "fmt.unpack(b'\\xf8\\xb0\\x08\\x08\\x18 "
-            "-\\x99\\xbd\\xbc\\x81\\x99"
-            "\\xa5\\x94\\x81\\x89\\x85"
-            "\\xc8\\x81\\x9d\\xbd\\xb4"
-            "\\x81\\x9d\\xd5\\xb4')",
-            setup="import bitstruct ; fmt = bitstruct.compile('s6u7r40b1t152')",
-            number=50000)
-        print("unpack time compiled: {} s ({} s/unpack)".format(time, time / 50000))
-
-    def test_performance_integers(self):
-        """Test pack/unpack performance with integers.
-
-        """
-
-        print()
-
-        time = timeit.timeit("pack('s13u7u35u1s9', "
-                             "-2, 22, 44567233, 0, 33)",
-                             setup="from bitstruct import pack",
-                             number=50000)
-        print("pack time: {} s ({} s/pack)".format(time, time / 50000))
-
-        time = timeit.timeit(
-            "fmt.pack(-2, 22, 44567233, 0, 33)",
-            setup="import bitstruct ; fmt = bitstruct.compile('s13u7u35u1s9')",
-            number=50000)
-        print("pack time compiled: {} s ({} s/pack)".format(time, time / 50000))
-
-        time = timeit.timeit("unpack('s13u7u35u1s9', "
-                             "b'\\xff\\xf1`\\x05P\\x15\\x82\\x10\\x80')",
-                             setup="from bitstruct import unpack",
-                             number=50000)
-        print("unpack time: {} s ({} s/unpack)".format(time, time / 50000))
-
-        time = timeit.timeit(
-            "fmt.unpack(b'\\xff\\xf1`\\x05P\\x15\\x82\\x10\\x80')",
-            setup="import bitstruct ; fmt = bitstruct.compile('s13u7u35u1s9')",
-            number=50000)
-        print("unpack time compiled: {} s ({} s/unpack)".format(time, time / 50000))
-
     def test_compile(self):
         cf = bitstruct.compile('u1u1s6u7u9')
 
@@ -599,7 +527,7 @@ class BitStructTest(unittest.TestCase):
             pack_into('u17', packed, 0, 1)
 
         self.assertEqual(str(cm.exception),
-                         'pack requires a buffer of at least 17 bits')
+                         'pack_into requires a buffer of at least 17 bits')
 
         packed = bytearray(b'\x00')
         pack_into('P4u4', packed, 0, 1)
